==> ckan-2.9.7.tar.gz: ckan-2.9.7/ckan/public/base/i18n/nl.js <==
{
  "": {
    "domain": "ckan",
    "lang": "nl",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "Add Filter": [
    null,
    "Filter toevoegen"
  ],
  "An Error Occurred": [
    null,
    "Er is een fout opgetreden"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Weet u zeker dat u deze actie uit wil voeren?"
  ],
  "Cancel": [
    null,
    "Afbreken"
  ],
  "Confirm": [
    null,
    "Bevestig"
  ],
  "Could not load view": [
    null,
    "Kon de view niet laden"
  ],
  "DataProxy returned an error": [
    null,
    "DataProxy gaf een fout terug"
  ],
  "DataStore returned an error": [
    null,
    "DataStore gaf een fout terug"
  ],
  "Edit": [
    null,
    "Bijwerk"
  ],
  "Failed to load data API information": [
    null,
    "Het laden van de API informatie data is mislukt"
  ],
  "File": [
    null,
    "Bestand"
  ],
  "Filters": [
    null,
    "Filters"
  ],
  "Follow": [
    null,
    "Volg"
  ],
  "Graph": [
    null,
    "Grafiek"
  ],
  "Grid": [
    null,
    "Grid"
  ],
  "Hide": [
    null,
    "verberg"
  ],
  "Image": [
    null,
    "Afbeelding"
  ],
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters",
    "Uw input is te kort, hij moet uit minimaal een karakter bestaan ",
    "Uw input is te kort, hij moet uit minimaal %(num)d karakters bestaan"
  ],
  "Link": [
    null,
    "Link"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "Gebruik een weblocatie (URL). Dit mag ook de URL van een API zijn."
  ],
  "Loading...": [
    null,
    "Laden..."
  ],
  "Map": [
    null,
    "Kaart"
  ],
  "No matches found": [
    null,
    "Geen overeenkomsten gevonden"
  ],
  "Please Confirm Action": [
    null,
    "Bevestig de actie"
  ],
  "Remove": [
    null,
    "Verwijder"
  ],
  "Resource uploaded": [
    null,
    "De bron is geupload"
  ],
  "Save order": [
    null,
    "Bewaar sortering"
  ],
  "Saving...": [
    null,
    "Opslaan..."
  ],
  "Select a field": [
    null,
    "Kies een veld"
  ],
  "Show more": [
    null,
    "Toon meer"
  ],
  "Start typing…": [
    null,
    "Begin met typen"
  ],
  "There are unsaved modifications to this form": [
    null,
    "Er zijn niet-opgeslagen wijzigingen in dit formulier"
  ],
  "There is no API data to load for this resource": [
    null,
    "Er is geen API data om deze bron te openen"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Kan de upload niet authenticeren"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Kan geen data vinden voor het geuploaden bestand"
  ],
  "Unable to upload file": [
    null,
    "Kan het bestand niet uploaden"
  ],
  "Unfollow": [
    null,
    "Ontvolgen"
  ],
  "Upload": [
    null,
    "Upload"
  ],
  "Upload a file": [
    null,
    "Upload een bestand"
  ],
  "Upload a file on your computer": [
    null,
    "Upload een bestand"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Bestand wordt geupload. Als u deze pagina verlaat stopt de upload. Weet u zeker dat u de pagina wilt verlaten?"
  ],
  "error loading view": [
    null,
    "fout bij het laden van de view"
  ]
}

==> ckan-2.9.11.tar.gz: ckan-2.9.11/ckan/public/base/i18n/nl.js <==
{
  "": {
    "domain": "ckan",
    "lang": "nl",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "Add Filter": [
    null,
    "Filter toevoegen"
  ],
  "An Error Occurred": [
    null,
    "Er is een fout opgetreden"
  ],
  "An error occured during AJAX request. Could not load view.": [
    null,
    "Er is een fout opgetreden tijdens het AJAX-verzoek. Kan weergave niet laden."
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Weet u zeker dat u deze actie uit wil voeren?"
  ],
  "Cancel": [
    null,
    "Afbreken"
  ],
  "Confirm": [
    null,
    "Bevestig"
  ],
  "Could not load view": [
    null,
    "Kon de view niet laden"
  ],
  "DataProxy returned an error": [
    null,
    "DataProxy gaf een fout terug"
  ],
  "DataStore returned an error": [
    null,
    "DataStore gaf een fout terug"
  ],
  "Edit": [
    null,
    "Bijwerk"
  ],
  "Failed to load data API information": [
    null,
    "Het laden van de API informatie data is mislukt"
  ],
  "File": [
    null,
    "Bestand"
  ],
  "Filters": [
    null,
    "Filters"
  ],
  "Follow": [
    null,
    "Volg"
  ],
  "Graph": [
    null,
    "Grafiek"
  ],
  "Grid": [
    null,
    "Grid"
  ],
  "Hide": [
    null,
    "verberg"
  ],
  "Image": [
    null,
    "Afbeelding"
  ],
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters",
    "Uw input is te kort, hij moet uit minimaal een karakter bestaan ",
    "Uw input is te kort, hij moet uit minimaal %(num)d karakters bestaan"
  ],
  "Link": [
    null,
    "Link"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "Gebruik een weblocatie (URL). Dit mag ook de URL van een API zijn."
  ],
  "Loading...": [
    null,
    "Laden..."
  ],
  "Map": [
    null,
    "Kaart"
  ],
  "No matches found": [
    null,
    "Geen overeenkomsten gevonden"
  ],
  "Please Confirm Action": [
    null,
    "Bevestig de actie"
  ],
  "Please select the file to upload again": [
    null,
    "Selecteer het bestand om opnieuw te uploaden"
  ],
  "Remove": [
    null,
    "Verwijder"
  ],
  "Reorder resource view": [
    null,
    "Bronweergave opnieuw ordenen"
  ],
  "Reorder resources": [
    null,
    "Bronnen opnieuw ordenen"
  ],
  "Resource uploaded": [
    null,
    "De bron is geüpload"
  ],
  "Save order": [
    null,
    "Bewaar sortering"
  ],
  "Saving...": [
    null,
    "Opslaan..."
  ],
  "Select a field": [
    null,
    "Kies een veld"
  ],
  "Show more": [
    null,
    "Toon meer"
  ],
  "Start typing…": [
    null,
    "Begin met typen"
  ],
  "There are unsaved modifications to this form": [
    null,
    "Er zijn niet-opgeslagen wijzigingen in dit formulier"
  ],
  "There is no API data to load for this resource": [
    null,
    "Er is geen API data om deze bron te openen"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Kan de upload niet authenticeren"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Kan geen data vinden voor het geüploade bestand"
  ],
  "Unable to upload file": [
    null,
    "Kan het bestand niet uploaden"
  ],
  "Unfollow": [
    null,
    "Ontvolgen"
  ],
  "Upload": [
    null,
    "Upload"
  ],
  "Upload a file": [
    null,
    "Upload een bestand"
  ],
  "Upload a file on your computer": [
    null,
    "Upload een bestand"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Bestand wordt geüpload. Als u deze pagina verlaat stopt de upload. Weet u zeker dat u de pagina wilt verlaten?"
  ],
  "You can rearrange the resources by dragging them using the arrow icon. Drag the resource to the right and place it to the desired location on the list. When you are done, click the \"Save order\" -button.": [
    null,
    "U kunt de bronnen opnieuw rangschikken door ze te slepen met behulp van het pijlpictogram. Sleep de bron naar rechts en plaats deze op de gewenste locatie in de lijst. Als u klaar bent, klikt u op de knop \"Bewaar sortering\"."
  ],
  "error loading view": [
    null,
    "fout bij het laden van de view"
  ]
}
